@@ -19,7 +19,7 @@ package org.trix.cuery.value;
  * DOCUMENT.
  * 
  * @author <a href="mailto:Teletha.T@gmail.com">Teletha Testarossa</a>
- * @version $ Id: AbstractCSSAngle.java,v 1.0 2005/08/09 20:09:47 Teletha Exp $
+ * @version $ Id: AbstractCSSAngle.java,v 1.01 2005/09/14 22:16:47 Teletha Exp $
  */
 public abstract class AbstractCSSAngle extends AbstractCSSValue implements CSSAngle {
 
@@ -32,6 +32,13 @@ public abstract class AbstractCSSAngle extends AbstractCSSValue implements CSSAn
     public AbstractCSSAngle(String angle, CSSValue previous) {
         super(previous);
 
+        // check unit
+        String unit = getDimensionUnitText();
+
+        if (angle.endsWith(unit)) {
+            angle = angle.substring(0, angle.length() - unit.length());
+        }
+
         this.stringValue = angle;
         this.floatValue = Float.parseFloat(angle);
     }
