@@ -17,6 +17,9 @@ package org.trix.cuery;
 
 import java.util.Set;
 
+import org.trix.cuery.filter.ElementFilter;
+import org.trix.cuery.filter.Filter;
+
 import junit.framework.TestCase;
 
 /**
@@ -29,9 +32,12 @@ public class CSSQueryTest extends TestCase {
 
     private static CSSQuery query;
 
+    private static CSSQuery queryNS;
+
     static {
         try {
             query = new CSSQuery("src/test/org/trix/cuery/cssQuery.xml");
+            queryNS = new CSSQuery("src/test/org/trix/cuery/cssQueryNS.xml");
         } catch (Exception e) {
             System.out.println(e);
         }
@@ -326,4 +332,37 @@ public class CSSQueryTest extends TestCase {
         elements = query.select("p:not(:contains(\"some\"))");
         assertEquals(4, elements.size());
     }
+
+    /**
+     * Test selector with namespace.
+     * 
+     * @throws Exception Test fails.
+     */
+    public void testNamespace() throws Exception {
+        String foo = "http://www.example.com";
+
+        // *
+        Set elements = queryNS.select("*");
+        assertEquals(10, elements.size());
+
+        // foo|*
+        Filter filter = new ElementFilter("foo", foo, "*");
+        elements = queryNS.select(filter);
+        assertEquals(5, elements.size());
+
+        // foo|p
+        filter = new ElementFilter("foo", foo, "p");
+        elements = queryNS.select(filter);
+        assertEquals(3, elements.size());
+        
+        // *|p
+        filter = new ElementFilter("*", null, "p");
+        elements = queryNS.select(filter);
+        assertEquals(4, elements.size());
+        
+        // |p
+        filter = new ElementFilter("", null, "p");
+        elements = queryNS.select(filter);
+        assertEquals(1, elements.size());
+    }
 }
